@@ -1,6 +1,6 @@
-package Module::Faker::Dist;
+package Module::Faker::Dist 0.023;
 # ABSTRACT: a fake CPAN distribution
-$Module::Faker::Dist::VERSION = '0.022';
+
 use Moose;
 
 use Module::Faker::File;
@@ -802,7 +802,7 @@ Module::Faker::Dist - a fake CPAN distribution
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -824,6 +824,18 @@ You can use the C<new> method on Module::Faker::Dist, of course, but it's a bit
 of a pain.  You might, instead, want to use C<from_struct>, which is very close
 to C<new>, but with more sugar.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 name
@@ -1019,7 +1031,7 @@ if specified, packages is an L<optlist|Data::OptList>
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
